"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
const codegen_1 = require("@azure-tools/codegen");
const type_1 = require("./type");
const linq_1 = require("@azure-tools/linq");
class Interface extends type_1.Type {
    constructor(parent, name, objectIntializer) {
        super(parent, name);
        this.apply(objectIntializer);
        parent.addInterface(this);
        if (!this.description.trim()) {
            this.description = '';
        }
    }
    get definition() {
        const colon = linq_1.length(this.interfaces) > 0 ? ' : ' : '';
        const implementsInterfaces = this.interfaces.map(v => v.declaration).join(',\n    ');
        const description = codegen_1.comment(this.description, codegen_1.docCommentPrefix);
        const methods = this.methods.sort(codegen_1.sortByName).map(m => m.interfaceDeclaration).join(codegen_1.EOL);
        const properties = this.properties.sort(codegen_1.sortByName).map(m => m.declaration).join(codegen_1.EOL);
        const partial = this.partial ? 'partial ' : '';
        return `
${description}
${this.attributeDeclaration}${this.accessModifier} ${partial}interface ${this.name}${colon}
    ${implementsInterfaces} 
{
${codegen_1.indent(properties, 1)}

${codegen_1.indent(methods, 1)}
}
`.trim();
    }
    get declaration() {
        return this.fullName;
    }
}
exports.Interface = Interface;
//# sourceMappingURL=interface.js.map